@@ -12,13 +12,18 @@
 #     See the License for the specific language governing permissions and
 #     limitations under the License.
 #
-from __future__ import absolute_import
-
 from fresco.response import Response
 
-__all__ = 'ResponseException', 'NotFound', 'Unauthorized',\
-          'Forbidden', 'BadRequest', 'Redirect', 'RedirectTemporary',\
-          'RedirectPermanent'
+__all__ = (
+    "ResponseException",
+    "NotFound",
+    "Unauthorized",
+    "Forbidden",
+    "BadRequest",
+    "Redirect",
+    "RedirectTemporary",
+    "RedirectPermanent",
+)
 
 
 class ResponseException(Exception):
@@ -26,16 +31,17 @@ class ResponseException(Exception):
     An exception class with an associated :class:`fresco.response.Response`
     instance that will render a suitable error page.
     """
-    response = None
+
+    response = Response()
 
     #: If true, the error response will be returned immediately without trying
     #: any other routes.
     is_final = True
 
     def __init__(self, content=None, **kwargs):
-        self.is_final = kwargs.pop('final', True)
+        self.is_final = kwargs.pop("final", True)
         if content:
-            kwargs['content'] = content
+            kwargs["content"] = content
         if kwargs:
             self.response = self.response.replace(**kwargs)
 
@@ -44,6 +50,7 @@ class NotFound(ResponseException):
     """\
     Raised when a view needs to signal a 404 not found condition.
     """
+
     response = Response.not_found()
 
     def __init__(self, content=None, **kwargs):
@@ -52,7 +59,7 @@ class NotFound(ResponseException):
         opportunity to handle the request. Only after other routes have been
         tried will an error response be returned.
         """
-        kwargs.setdefault('final', False)
+        kwargs.setdefault("final", False)
         super(NotFound, self).__init__(content, **kwargs)
 
 
@@ -60,7 +67,8 @@ class BadRequest(ResponseException):
     """\
     Return a 400 Bad Request response
     """
-    response = Response(['Bad request'], status=400)
+
+    response = Response(["Bad request"], status=400)
 
 
 class Unauthorized(ResponseException):
@@ -70,7 +78,8 @@ class Unauthorized(ResponseException):
     Use this when you want to flag that the user does not have permission to
     access a resource but may be able to gain access, eg by logging in.
     """
-    response = Response(['Unauthorized'], status=401)
+
+    response = Response(["Unauthorized"], status=401)
 
 
 class Forbidden(ResponseException):
@@ -82,7 +91,8 @@ class Forbidden(ResponseException):
     already logged in, but their account does not have the right access
     permissions)
     """
-    response = Response(['Forbidden'], status=403)
+
+    response = Response(["Forbidden"], status=403)
 
 
 class RedirectTemporary(ResponseException):
@@ -91,9 +101,11 @@ class RedirectTemporary(ResponseException):
 
         raise RedirectTemporary('http://example.org/')
     """
+
     def __init__(self, *args, **kwargs):
         self.response = Response.redirect(*args, **kwargs)
 
+
 Redirect = RedirectTemporary
 
 
@@ -104,6 +116,7 @@ class RedirectPermanent(ResponseException):
         raise RedirectPermanent('http://example.org/')
 
     """
+
     def __init__(self, *args, **kwargs):
         self.response = Response.redirect_permanent(*args, **kwargs)
 
@@ -118,6 +131,7 @@ class MethodNotAllowed(ResponseException):
     """\
     The URL is valid, but does not respond to the requested method
     """
+
     def __init__(self, valid_methods, **kwargs):
         self.response = Response.method_not_allowed(valid_methods)
         super(MethodNotAllowed, self).__init__(**kwargs)
@@ -132,7 +146,8 @@ class TooManyRequests(ResponseException):
     condition, and MAY include a Retry-After header indicating how long
     to wait before making a new request.
     """
-    response = Response(['Too many requests'], status=429)
+
+    response = Response(["Too many requests"], status=429)
 
 
 class MissingRouteArg(BadRequest):
