@@ -12,36 +12,116 @@
 #     See the License for the specific language governing permissions and
 #     limitations under the License.
 #
-from __future__ import absolute_import
-
 from operator import attrgetter, itemgetter, methodcaller
 from fresco.exceptions import MissingRouteArg
 from itertools import cycle
 
-__all__ = ('routearg', 'FormArg', 'PostArg', 'QueryArg', 'GetArg', 'CookieArg',
-           'SessionArg', 'RequestObject',
-           'FormData', 'PostData', 'QueryData', 'GetData')
+__all__ = (
+    "routearg",
+    "FormArg",
+    "PostArg",
+    "QueryArg",
+    "GetArg",
+    "CookieArg",
+    "SessionArg",
+    "RequestObject",
+    "FormData",
+    "PostData",
+    "QueryData",
+    "GetData",
+)
 
-_marker = []
+_marker = object()
 
 magicmethods = [
-    '__abs__', '__add__', '__and__', '__call__', '__cmp__', '__coerce__',
-    '__complex__', '__contains__', '__del__', '__delattr__', '__delete__',
-    '__delitem__', '__delslice__', '__div__', '__divmod__', '__enter__',
-    '__eq__', '__exit__', '__float__', '__floordiv__',
-    '__ge__', '__getattr__', '__getitem__', '__getslice__',
-    '__gt__', '__hash__', '__hex__', '__iadd__', '__iand__', '__idiv__',
-    '__ifloordiv__', '__ilshift__', '__imod__', '__imul__', '__index__',
-    '__int__', '__invert__', '__iop__', '__ior__', '__ipow__', '__irshift__',
-    '__isub__', '__iter__', '__itruediv__', '__ixor__', '__le__', '__len__',
-    '__long__', '__lshift__', '__lt__', '__mod__', '__mul__', '__ne__',
-    '__neg__', '__nonzero__', '__oct__', '__op__', '__or__', '__pos__',
-    '__pow__', '__radd__', '__rand__', '__rcmp__', '__rdiv__', '__rdivmod__',
-    '__repr__', '__reversed__', '__rfloordiv__', '__rlshift__', '__rmod__',
-    '__rmul__', '__rop__', '__ror__', '__rpow__', '__rrshift__', '__rshift__',
-    '__rsub__', '__rtruediv__', '__rxor__', '__setattr__', '__setitem__',
-    '__setslice__', '__str__', '__sub__', '__truediv__', '__unicode__',
-    '__weakref__', '__xor__']
+    "__abs__",
+    "__add__",
+    "__and__",
+    "__call__",
+    "__cmp__",
+    "__coerce__",
+    "__complex__",
+    "__contains__",
+    "__del__",
+    "__delattr__",
+    "__delete__",
+    "__delitem__",
+    "__delslice__",
+    "__div__",
+    "__divmod__",
+    "__enter__",
+    "__eq__",
+    "__exit__",
+    "__float__",
+    "__floordiv__",
+    "__ge__",
+    "__getattr__",
+    "__getitem__",
+    "__getslice__",
+    "__gt__",
+    "__hash__",
+    "__hex__",
+    "__iadd__",
+    "__iand__",
+    "__idiv__",
+    "__ifloordiv__",
+    "__ilshift__",
+    "__imod__",
+    "__imul__",
+    "__index__",
+    "__int__",
+    "__invert__",
+    "__iop__",
+    "__ior__",
+    "__ipow__",
+    "__irshift__",
+    "__isub__",
+    "__iter__",
+    "__itruediv__",
+    "__ixor__",
+    "__le__",
+    "__len__",
+    "__long__",
+    "__lshift__",
+    "__lt__",
+    "__mod__",
+    "__mul__",
+    "__ne__",
+    "__neg__",
+    "__nonzero__",
+    "__oct__",
+    "__op__",
+    "__or__",
+    "__pos__",
+    "__pow__",
+    "__radd__",
+    "__rand__",
+    "__rcmp__",
+    "__rdiv__",
+    "__rdivmod__",
+    "__repr__",
+    "__reversed__",
+    "__rfloordiv__",
+    "__rlshift__",
+    "__rmod__",
+    "__rmul__",
+    "__rop__",
+    "__ror__",
+    "__rpow__",
+    "__rrshift__",
+    "__rshift__",
+    "__rsub__",
+    "__rtruediv__",
+    "__rxor__",
+    "__setattr__",
+    "__setitem__",
+    "__setslice__",
+    "__str__",
+    "__sub__",
+    "__truediv__",
+    "__unicode__",
+    "__xor__",
+]
 
 
 def map_magics(dest):
@@ -50,10 +130,11 @@ def map_magics(dest):
         for item in magicmethods:
             setattr(cls, item, dest_method)
         return cls
+
     return map_magics
 
 
-@map_magics('raise_exception')
+@map_magics("raise_exception")
 class LazyException(object):
     """
     A lazy exception uses magic methods to intercept any access to the object
@@ -61,10 +142,10 @@ class LazyException(object):
     """
 
     def __init__(self, exception):
-        self.__dict__['_exception'] = exception
+        self.__dict__["_exception"] = exception
 
     def raise_exception(self, *args, **kwargs):
-        raise self.__dict__['_exception']
+        raise self.__dict__["_exception"]
 
 
 class RouteArg(object):
@@ -132,9 +213,11 @@ def routearg(func, *args, **kwargs):
         Route('/', GET, myview, is_a_friend=routearg(name_is, 'fred', 'jim'))
 
     """
+
     class _RouteArg(RouteArg):
         def __call__(self, request):
             return func(request, *args, **kwargs)
+
     return _RouteArg()
 
 
@@ -143,10 +226,10 @@ class RequestArg(RouteArg):
     Extract a view keyword argument from the request object.
     """
 
-    query = attrgetter('query')
-    form = attrgetter('form')
-    cookies = attrgetter('cookies')
-    session = attrgetter('session')
+    query = attrgetter("query")
+    form = attrgetter("form")
+    cookies = attrgetter("cookies")
+    session = attrgetter("session")
 
     #: Source for the request variable
     source = form
@@ -155,14 +238,20 @@ class RequestArg(RouteArg):
     #: input
     converter_exceptions = (ValueError, TypeError)
 
-    def __init__(self, converter=None, key=None,
-                 default=_marker, exception=MissingRouteArg):
+    def __init__(
+        self,
+        converter=None,
+        key=None,
+        default=_marker,
+        exception=MissingRouteArg,
+    ):
         super(RequestArg, self).__init__(default, exception)
         self.formkey = key
         self.is_list = isinstance(converter, list)
         if self.is_list:
-            self.converter = lambda vs: [c(v)
-                                         for c, v in zip(cycle(converter), vs)]
+            self.converter = lambda vs: [
+                c(v) for c, v in zip(cycle(converter), vs)
+            ]
         else:
             self.converter = converter
 
@@ -170,18 +259,20 @@ class RequestArg(RouteArg):
         if self.formkey is None:
             self.formkey = name
         if self.is_list:
-            self.getter = methodcaller('getlist', self.formkey)
+            self.getter = methodcaller("getlist", self.formkey)
         else:
             self.getter = itemgetter(self.formkey)
 
     def __call__(self, request):
         try:
-            value = self.getter(self.source(request))
+            value = self.getter(self.source(request))  # type: ignore
         except KeyError:
             if self.required:
                 return LazyException(
-                            self.exception('No value provided for %s' %
-                                           (self.formkey,)))
+                    self.exception(
+                        "No value provided for %s" % (self.formkey,)
+                    )
+                )
             else:
                 return self.default
 
@@ -190,8 +281,8 @@ class RequestArg(RouteArg):
                 value = self.converter(value)
         except self.converter_exceptions:
             value = LazyException(
-                        self.exception('Invalid value for %s' %
-                                       (self.formkey,)))
+                self.exception("Invalid value for %s" % (self.formkey,))
+            )
 
         return value
 
@@ -206,6 +297,7 @@ class RequestObject(RouteArg):
         def view(formdata, request):
             ...
     """
+
     def __call__(self, request):
         return request
 
@@ -220,12 +312,13 @@ class JSONPayload(RouteArg):
         def view(formdata, request):
             ...
     """
+
     def __call__(self, request):
-        if request.content_type == 'application/json':
+        if request.content_type == "application/json":
             return request.get_json()
         if self.default is not _marker:
             return self.default
-        return LazyException(self.exception('JSON payload missing'))
+        return LazyException(self.exception("JSON payload missing"))
 
 
 class GetData(RouteArg):
@@ -261,6 +354,7 @@ class PostData(RouteArg):
     def __call__(self, request):
         return request.form
 
+
 #: FormData may be used as an alias for PostData
 FormData = PostData
 
@@ -275,6 +369,7 @@ class CookieArg(RequestArg):
         def view(message, message):
             return Response([message])
     """
+
     source = RequestArg.cookies
 
     def getter(self, cookies):
@@ -298,8 +393,10 @@ class GetArg(RequestArg):
         def view(a, b):
             return Response(['a + b = %d' % (a + b)])
     """
+
     source = RequestArg.query
 
+
 #: QueryArg may be used as an alias for GetArg
 QueryArg = GetArg
 
@@ -315,8 +412,10 @@ class PostArg(RequestArg):
             return Response(['a * b = %d' % (a * b)])
 
     """
+
     source = RequestArg.form
 
+
 #: FormArg may be used as an alias for PostArg
 FormArg = PostArg
 
@@ -332,4 +431,5 @@ class SessionArg(RequestArg):
             return Response(['a * b = %d' % (a * b)])
 
     """
+
     source = RequestArg.session
