@@ -16,11 +16,9 @@
 """
 Common utilities for writing applications in fresco
 """
-from __future__ import absolute_import
-
 from fresco.exceptions import NotFound
 
-__all__ = ['object_or_404']
+__all__ = ["object_or_404"]
 
 
 def object_or_404(ob, exception=NotFound):
@@ -38,7 +36,10 @@ def fq_path(ob):
     Return the fully qualified path of ``ob``, expected to be a function or
     method
     """
-    name = getattr(ob, '__qualname__', None) or \
-            getattr(ob, '__name__', None) or repr(ob)
-    module = getattr(ob, '__module__', None) or ''
-    return '{}.{}'.format(module, name)
+    name = (
+        getattr(ob, "__qualname__", None)
+        or getattr(ob, "__name__", None)
+        or repr(ob)
+    )
+    module = getattr(ob, "__module__", None) or ""
+    return "{}.{}".format(module, name)
